﻿using System.Windows;

using DevExpress.Xpf.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.gridControl.ItemsSource = new NorthwindEntities().Products;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 테이블 뷰 신규 행 초기화시 처리하기 - tableView_InitNewRow(sender, e)

        /// <summary>
        /// 테이블 뷰 신규 행 초기화시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void tableView_InitNewRow(object sender, InitNewRowEventArgs e)
        {
            this.gridControl.SetCellValue(e.RowHandle, "UnitPrice"   , 10   );
            this.gridControl.SetCellValue(e.RowHandle, "Discontinued", false);
            this.gridControl.SetCellValue(e.RowHandle, "UnitsOnOrder", 1    );
        }

        #endregion
        #region 테이블 뷰 행 무결성 조사시 처리하기 - tableView_ValidateRow(sender, e)

        /// <summary>
        /// 테이블 뷰 행 무결성 조사시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void tableView_ValidateRow(object sender, GridRowValidationEventArgs e)
        {
            if(e.Row == null)
            {
                return;
            }

            if(e.RowHandle == GridControl.NewItemRowHandle)
            {
                e.IsValid =  !string.IsNullOrEmpty((e.Row as Product).ProductName);
            }
        }

        #endregion
        #region 테이블 뷰 무효한 행 예외 처리하기 - tableView_InvalidRowException(sender, e)

        /// <summary>
        /// 테이블 뷰 무효한 행 예외 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void tableView_InvalidRowException(object sender, InvalidRowExceptionEventArgs e)
        {
            if(e.RowHandle == GridControl.NewItemRowHandle)
            {
                e.ErrorText     = "Please enter the Product name. ";
                e.WindowCaption = "Input Error";

                this.gridControl.CurrentColumn = this.gridControl.Columns["ProductName"];
            }
        }

        #endregion
    }
}